pub enum LeafErrorKind {
EmptyStack,
InvalidInstruction(Error),
NotPushBytes,
}Expand description
Errors that may occur while reconstructing a leaf’s scriptPubKey.
Variants
EmptyStack
The witness or scriptsig was empty, so nothing could be inspected.
InvalidInstruction(Error)
The scriptsig data could not be parsed into Instructions.
NotPushBytes
The last instruction in the scriptsig was not an OP_PUSHBYTES.