fn get_pk_hash(input: &TxIn) -> Result<PubkeyHash, LeafErrorKind>Expand description
Computes the public key hash from the pushed key in the input’s scriptSig.
fn get_pk_hash(input: &TxIn) -> Result<PubkeyHash, LeafErrorKind>Computes the public key hash from the pushed key in the input’s scriptSig.