Function process_proof

pub fn process_proof<F, E>(
    leaves: &[CompactLeafData],
    txdata: &[Transaction],
    height: u32,
    get_block_hash: F,
) -> Result<(Vec<Hash>, HashMap<OutPoint, UtxoData>), E>
where F: Fn(u32) -> Result<BlockHash, E>, E: From<UtreexoLeafError>,
This function processes a proof of inclusion for a given block. It takes in the CompactLeafData for this block, this block’s transactions, the height and a function to get the block hash for a given height. Then returns a Result containing a vector with hashes for deleted leaves, and a UtxoMap, which is defined as HashMap<OutPoint, UtxoData>.