pub struct UtreexoLeafError {
pub leaf: CompactLeafData,
pub txid: Txid,
pub vin: usize,
pub kind: LeafErrorKind,
}Expand description
Error while reconstructing a leaf’s scriptPubKey, returned by process_proof.
This error is triggered if the input lacks the hashed data required by the ScriptPubKeyKind (i.e., the public key for P2PKH, the redeem script for P2SH, or the witness public key and witness script for P2WPKH/P2WSH).
Fields
leaf: CompactLeafDatatxid: Txidvin: usizekind: LeafErrorKindTrait Implementations
Sourceimpl Debug for UtreexoLeafError
impl Debug for UtreexoLeafError
Sourceimpl Display for UtreexoLeafError
impl Display for UtreexoLeafError
Sourceimpl From<UtreexoLeafError> for BlockchainError
impl From<UtreexoLeafError> for BlockchainError
Sourcefn from(e: UtreexoLeafError) -> Self
fn from(e: UtreexoLeafError) -> Self
Converts to this type from the input type.